@@ -10,8 +10,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/kauth/kaprocs.c,v 1.15 2003/11/23 04:53:35 jaltman Exp $");
 
 #include <afs/stds.h>
 #include <errno.h>
@@ -40,6 +38,7 @@ RCSID
 #include <des.h>
 #include <afs/cellconfig.h>
 #include <afs/auth.h>
+#include <afs/com_err.h>
 #include "kautils.h"
 #include "kaserver.h"
 #include "kalog.h"
@@ -176,7 +175,7 @@ get_time(timeP, tt, admin)
 		} else {
 		    es_Report
 			("in get_time: set_password failed because: %s\n",
-			 error_message(code));
+			 afs_error_message(code));
 		    return code;
 		}
 	    }
@@ -1032,7 +1031,8 @@ PrepareTicketAnswer(oanswer, challenge, ticket, ticketLen, sessionKey, start,
 
     code = KAANSWERTOOLONG;
     if (oanswer->MaxSeqLen <
-	sizeof(struct ka_ticketAnswer) - 5 * MAXKTCNAMELEN)
+	sizeof(struct ka_ticketAnswer) - 5 * MAXKTCNAMELEN - MAXKTCTICKETLEN +
+	ticketLen)
 	return code;
 
     answer = (struct ka_ticketAnswer *)oanswer->SeqBody;
@@ -1958,7 +1958,8 @@ GetTicket(version, call, kvno, authDomain, aticket, sname, sinstance, atimes,
     case 0:
 	code = KAANSWERTOOLONG;
 	if (oanswer->MaxSeqLen <
-	    sizeof(struct ka_getTicketAnswer) - 5 * MAXKTCNAMELEN)
+	    sizeof(struct ka_getTicketAnswer) - 5 * MAXKTCNAMELEN -
+	    MAXKTCTICKETLEN + ticketLen)
 	    goto abort;
 
 	answer = (struct ka_getTicketAnswer *)oanswer->SeqBody;
