@@ -14,28 +14,24 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/rxkad/rxkad_server.c,v 1.14 2003/11/29 20:23:35 jaltman Exp $");
 
 #include <afs/stds.h>
 #include <sys/types.h>
+#if (defined(AFS_AIX_ENV) && defined(KERNEL) && !defined(UKERNEL)) || defined(AFS_AUX_ENV) || defined(AFS_SUN5_ENV) 
+#include <sys/systm.h>
+#endif
 #include <time.h>
 #ifdef AFS_NT40_ENV
 #include <winsock2.h>
 #else
 #include <netinet/in.h>
 #endif
-#ifdef HAVE_STRING_H
 #include <string.h>
-#else
-#ifdef HAVE_STRINGS_H
-#include <strings.h>
-#endif
-#endif
 #include <rx/rx.h>
 #include <rx/xdr.h>
 #include <des.h>
 #include <afs/afsutil.h>
+#include <des/stats.h>
 #include "private_data.h"
 #define XPRT_RXKAD_SERVER
 
@@ -59,9 +55,9 @@ static struct rx_securityOps rxkad_server_ops = {
     rxkad_CheckPacket,		/* check data packet */
     rxkad_DestroyConnection,
     rxkad_GetStats,
-	0, /* spare 1 */
-	0, /* spare 2 */
-	0, /* spare 3 */
+    rxkad_SetConfiguration,
+    0,				/* spare 2 */
+    0,				/* spare 3 */
 };
 extern afs_uint32 rx_MyMaxSendSize;
 
@@ -79,8 +75,8 @@ static fc_KeySchedule random_int32_schedule;
 
 #include <assert.h>
 pthread_mutex_t rxkad_random_mutex;
-#define LOCK_RM assert(pthread_mutex_lock(&rxkad_random_mutex)==0);
-#define UNLOCK_RM assert(pthread_mutex_unlock(&rxkad_random_mutex)==0);
+#define LOCK_RM assert(pthread_mutex_lock(&rxkad_random_mutex)==0)
+#define UNLOCK_RM assert(pthread_mutex_unlock(&rxkad_random_mutex)==0)
 #else
 #define LOCK_RM
 #define UNLOCK_RM
@@ -92,8 +88,10 @@ init_random_int32(void)
     struct timeval key;
 
     gettimeofday(&key, NULL);
-    LOCK_RM fc_keysched(&key, random_int32_schedule);
-UNLOCK_RM}
+    LOCK_RM;
+    fc_keysched(&key, random_int32_schedule);
+    UNLOCK_RM;
+}
 
 static afs_int32
 get_random_int32(void)
@@ -101,9 +99,11 @@ get_random_int32(void)
     static struct timeval seed;
     afs_int32 rc;
 
-    LOCK_RM fc_ecb_encrypt(&seed, &seed, random_int32_schedule, ENCRYPT);
+    LOCK_RM;
+    fc_ecb_encrypt(&seed, &seed, random_int32_schedule, ENCRYPT);
     rc = seed.tv_sec;
-    UNLOCK_RM return rc;
+    UNLOCK_RM;
+    return rc;
 }
 
 /* Called with four parameters.  The first is the level of encryption, as
@@ -156,8 +156,8 @@ rxkad_NewServerSecurityObject(rxkad_level level, char *get_key_rock,
     tsp->user_ok = user_ok;	/* to inform server of client id. */
     init_random_int32();
 
-    LOCK_RXKAD_STATS rxkad_stats_serverObjects++;
-    UNLOCK_RXKAD_STATS return tsc;
+    INC_RXKAD_STATS(serverObjects);
+    return tsc;
 }
 
 /* server: called to tell if a connection authenticated properly */
@@ -232,8 +232,8 @@ rxkad_GetChallenge(struct rx_securityClass *aobj, struct rx_connection *aconn,
     rx_packetwrite(apacket, 0, challengeSize, challenge);
     rx_SetDataSize(apacket, challengeSize);
     sconn->tried = 1;
-    LOCK_RXKAD_STATS rxkad_stats.challengesSent++;
-    UNLOCK_RXKAD_STATS return 0;
+    INC_RXKAD_STATS(challengesSent);
+    return 0;
 }
 
 /* server: process a response to a challenge packet */
@@ -320,12 +320,14 @@ rxkad_CheckResponse(struct rx_securityClass *aobj,
      * If the alternate decoder is not present, or returns -1, then
      * assume the ticket is of the default style.
      */
-    if (code == -1 && (kvno == RXKAD_TKT_TYPE_KERBEROS_V5)
-	|| (kvno == RXKAD_TKT_TYPE_KERBEROS_V5_ENCPART_ONLY)) {
+    if (code == -1 && ((kvno == RXKAD_TKT_TYPE_KERBEROS_V5)
+	|| (kvno == RXKAD_TKT_TYPE_KERBEROS_V5_ENCPART_ONLY))) {
 	code =
 	    tkt_DecodeTicket5(tix, tlen, tsp->get_key, tsp->get_key_rock,
 			      kvno, client.name, client.instance, client.cell,
-			      &sessionkey, &host, &start, &end);
+			      &sessionkey, &host, &start, &end, 
+			      tsp->flags & RXS_CONFIG_FLAGS_DISABLE_DOTCHECK,
+			      tsp->alt_decrypt);
 	if (code)
 	    return code;
     }
@@ -344,13 +346,15 @@ rxkad_CheckResponse(struct rx_securityClass *aobj,
 			     client.instance, client.cell, &sessionkey, &host,
 			     &start, &end);
 	if (code)
-	    return RXKADBADTICKET;
+	    return code;
     }
     code = tkt_CheckTimes(start, end, time(0));
-    if (code == -1)
-	return RXKADEXPIRED;
-    else if (code <= 0)
+    if (code == 0) 
 	return RXKADNOAUTH;
+    else if (code == -1)
+	return RXKADEXPIRED;
+    else if (code < -1)
+	return RXKADBADTICKET;
 
     code = fc_keysched(&sessionkey, sconn->keysched);
     if (code)
@@ -397,11 +401,9 @@ rxkad_CheckResponse(struct rx_securityClass *aobj,
 	return RXKADLEVELFAIL;
     sconn->level = level;
     rxkad_SetLevel(aconn, sconn->level);
-    LOCK_RXKAD_STATS rxkad_stats.responses[rxkad_LevelIndex(sconn->level)]++;
-    UNLOCK_RXKAD_STATS
-	/* now compute endpoint-specific info used for computing 16 bit checksum */
-	rxkad_DeriveXORInfo(aconn, sconn->keysched, sconn->ivec,
-			    sconn->preSeq);
+    INC_RXKAD_STATS(responses[rxkad_LevelIndex(sconn->level)]);
+    /* now compute endpoint-specific info used for computing 16 bit checksum */
+    rxkad_DeriveXORInfo(aconn, sconn->keysched, sconn->ivec, sconn->preSeq);
 
     /* otherwise things are ok */
     sconn->expirationTime = end;
@@ -450,3 +452,36 @@ rxkad_GetServerInfo(struct rx_connection * aconn, rxkad_level * level,
     } else
 	return RXKADNOAUTH;
 }
+
+/* Set security object configuration variables */
+afs_int32 rxkad_SetConfiguration(struct rx_securityClass *aobj,
+                                 struct rx_connection *aconn, 
+                                 rx_securityConfigVariables atype,
+		                         void * avalue, void **currentValue)
+{
+    struct rxkad_sprivate *private = 
+    (struct rxkad_sprivate *) aobj->privateData;
+
+    switch (atype) {
+    case RXS_CONFIG_FLAGS:
+        if (currentValue) {
+            *((afs_uint32 *)currentValue) = private->flags;
+        } else { 
+            private->flags = (afs_uint32) avalue;
+        }
+        break;
+    default:
+        break;
+    }
+    return 0;
+}
+
+int rxkad_SetAltDecryptProc(struct rx_securityClass *aobj,
+			    rxkad_alt_decrypt_func alt_decrypt)
+{
+    struct rxkad_sprivate *private =
+    (struct rxkad_sprivate *)aobj->privateData;
+
+    private->alt_decrypt = alt_decrypt;
+    return 0;
+}
