@@ -10,11 +10,12 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/vlserver/vlserver.c,v 1.12 2001/08/08 00:04:22 shadow Exp $");
 
 #include <afs/stds.h>
 #include <sys/types.h>
 #include <signal.h>
+#include <sys/stat.h>
+#include <string.h>
 #ifdef HAVE_FCNTL_H
 #include <fcntl.h>
 #endif
@@ -33,6 +34,7 @@ RCSID("$Header: /cvs/openafs/src/vlserver/vlserver.c,v 1.12 2001/08/08 00:04:22
 #include <netinet/in.h>
 #endif
 #include <stdio.h>
+
 #include <rx/xdr.h>
 #include <rx/rx.h>
 #include <rx/rx_globals.h>
@@ -52,27 +54,37 @@ int lwps = 9;
 
 struct vldstats dynamic_statistics;
 struct ubik_dbase *VL_dbase;
-afs_uint32	HostAddress[MAXSERVERID+1];
+afs_uint32 HostAddress[MAXSERVERID + 1];
 extern int afsconf_CheckAuth();
 extern int afsconf_ServerAuth();
 
-extern afs_int32 ubik_lastYesTime;
-extern afs_int32 ubik_nBuffers;
-
-static	CheckSignal();
+static void *CheckSignal(void*);
 int LogLevel = 0;
 int smallMem = 0;
-int rxJumbograms = 1;  /* default is to send and receive jumbo grams */
+int rxJumbograms = 0;		/* default is to not send and receive jumbo grams */
+int rxMaxMTU = -1;
+afs_int32 rxBind = 0;
+int rxkadDisableDotCheck = 0;
+int debuglevel = 0;
 
-static void CheckSignal_Signal()       {IOMGR_SoftSig(CheckSignal, 0);}
+#define ADDRSPERSITE 16         /* Same global is in rx/rx_user.c */
+afs_uint32 SHostAddrs[ADDRSPERSITE];
 
-static CheckSignal()
+static void
+CheckSignal_Signal()
+{
+    IOMGR_SoftSig(CheckSignal, 0);
+}
+
+static void *
+CheckSignal(void *unused)
 {
     register int i, errorcode;
-    struct ubik_trans	*trans;
+    struct ubik_trans *trans;
 
-    if (errorcode = Init_VLdbase(&trans, LOCKREAD, VLGETSTATS-VL_LOWEST_OPCODE))
-	return errorcode;
+    if (errorcode =
+	Init_VLdbase(&trans, LOCKREAD, VLGETSTATS - VL_LOWEST_OPCODE))
+	return (void *)errorcode;
     VLog(0, ("Dump name hash table out\n"));
     for (i = 0; i < HASHSIZE; i++) {
 	HashNDump(trans, i);
@@ -81,43 +93,45 @@ static CheckSignal()
     for (i = 0; i < HASHSIZE; i++) {
 	HashIdDump(trans, i);
     }
-    return(ubik_EndTrans(trans));
-} /*CheckSignal*/
+    return ((void *)ubik_EndTrans(trans));
+}				/*CheckSignal */
 
 
 /* Initialize the stats for the opcodes */
-void initialize_dstats ()
-{   int i;
+void
+initialize_dstats()
+{
+    int i;
 
     dynamic_statistics.start_time = (afs_uint32) time(0);
-    for (i=0; i< MAX_NUMBER_OPCODES; i++) {
+    for (i = 0; i < MAX_NUMBER_OPCODES; i++) {
 	dynamic_statistics.requests[i] = 0;
 	dynamic_statistics.aborts[i] = 0;
     }
 }
 
 /* check whether caller is authorized to manage RX statistics */
-int vldb_rxstat_userok(call)
-    struct rx_call *call;
+int
+vldb_rxstat_userok(call)
+     struct rx_call *call;
 {
-    return afsconf_SuperUser(vldb_confdir, call, (char *)0);
+    return afsconf_SuperUser(vldb_confdir, call, NULL);
 }
 
 /* Main server module */
 
 #include "AFS_component_version_number.c"
 
-main (argc, argv)
-int	argc;
-char	**argv;
+main(argc, argv)
+     int argc;
+     char **argv;
 {
-    register afs_int32   code;
-    afs_int32		    myHost;
-    struct rx_service	    *tservice;
+    register afs_int32 code;
+    afs_int32 myHost;
+    struct rx_service *tservice;
     struct rx_securityClass *sc[3];
-    extern struct rx_securityClass *rxnull_NewServerSecurityObject();
-    extern int		    VL_ExecuteRequest();
-    extern int		    RXSTATS_ExecuteRequest();
+    extern int VL_ExecuteRequest();
+    extern int RXSTATS_ExecuteRequest();
     struct afsconf_dir *tdir;
     struct ktc_encryptionKey tkey;
     struct afsconf_cell info;
@@ -127,7 +141,8 @@ char	**argv;
     extern int rx_extraPackets;
     char commandLine[150];
     char clones[MAXHOSTSPERCELL];
- 
+    afs_uint32 host = ntohl(INADDR_ANY);
+
 #ifdef	AFS_AIX32_ENV
     /*
      * The following signal action for AIX is necessary so that in case of a 
@@ -136,57 +151,92 @@ char	**argv;
      * generated which, in many cases, isn't too useful.
      */
     struct sigaction nsa;
-    
-    rx_extraPackets = 100;  /* should be a switch, I guess... */
+
+    rx_extraPackets = 100;	/* should be a switch, I guess... */
     sigemptyset(&nsa.sa_mask);
     nsa.sa_handler = SIG_DFL;
     nsa.sa_flags = SA_FULLDUMP;
     sigaction(SIGABRT, &nsa, NULL);
     sigaction(SIGSEGV, &nsa, NULL);
 #endif
+    osi_audit_init();
+
     /* Parse command line */
-    for	(index=1; index	< argc;	index++) {
+    for (index = 1; index < argc; index++) {
 	if (strcmp(argv[index], "-noauth") == 0) {
 	    noAuth = 1;
-
 	} else if (strcmp(argv[index], "-p") == 0) {
 	    lwps = atoi(argv[++index]);
 	    if (lwps > MAXLWP) {
-		printf("Warning: '-p %d' is too big; using %d instead\n", lwps, MAXLWP);
+		printf("Warning: '-p %d' is too big; using %d instead\n",
+		       lwps, MAXLWP);
 		lwps = MAXLWP;
 	    }
-
+	} else if (strcmp(argv[index], "-d") == 0) {
+	    if ((index + 1) >= argc) {
+		fprintf(stderr, "missing argument for -d\n"); 
+		return -1; 
+	    }
+	    debuglevel = atoi(argv[++index]);
+	    LogLevel = debuglevel;
 	} else if (strcmp(argv[index], "-nojumbo") == 0) {
 	    rxJumbograms = 0;
+	} else if (strcmp(argv[index], "-jumbo") == 0) {
+	    rxJumbograms = 1;
+	} else if (strcmp(argv[index], "-rxbind") == 0) {
+	    rxBind = 1;
+	} else if (strcmp(argv[index], "-allow-dotted-principals") == 0) {
+	    rxkadDisableDotCheck = 1;
+	} else if (!strcmp(argv[index], "-rxmaxmtu")) {
+	    if ((index + 1) >= argc) {
+		fprintf(stderr, "missing argument for -rxmaxmtu\n"); 
+		return -1; 
+	    }
+	    rxMaxMTU = atoi(argv[++index]);
+	    if ((rxMaxMTU < RX_MIN_PACKET_SIZE) || 
+		(rxMaxMTU > RX_MAX_PACKET_DATA_SIZE)) {
+		printf("rxMaxMTU %d invalid; must be between %d-%d\n",
+		       rxMaxMTU, RX_MIN_PACKET_SIZE, 
+		       RX_MAX_PACKET_DATA_SIZE);
+		return -1;
+	    }
 
 	} else if (strcmp(argv[index], "-smallmem") == 0) {
 	    smallMem = 1;
 
 	} else if (strcmp(argv[index], "-trace") == 0) {
 	    extern char rxi_tracename[80];
-	    strcpy (rxi_tracename, argv[++index]);
+	    strcpy(rxi_tracename, argv[++index]);
 
+       } else if (strcmp(argv[index], "-auditlog") == 0) {
+           char *fileName = argv[++index];
+
+           osi_audit_file(fileName);
 	} else if (strcmp(argv[index], "-enable_peer_stats") == 0) {
 	    rx_enablePeerRPCStats();
 	} else if (strcmp(argv[index], "-enable_process_stats") == 0) {
 	    rx_enableProcessRPCStats();
 #ifndef AFS_NT40_ENV
-	} else if (strcmp(argv[index], "-syslog")==0) {
+	} else if (strcmp(argv[index], "-syslog") == 0) {
 	    /* set syslog logging flag */
 	    serverLogSyslog = 1;
-	} else if (strncmp(argv[index], "-syslog=", 8)==0) {
+	} else if (strncmp(argv[index], "-syslog=", 8) == 0) {
 	    serverLogSyslog = 1;
-	    serverLogSyslogFacility = atoi(argv[index]+8);
+	    serverLogSyslogFacility = atoi(argv[index] + 8);
 #endif
 	} else {
 	    /* support help flag */
 #ifndef AFS_NT40_ENV
 	    printf("Usage: vlserver [-p <number of processes>] [-nojumbo] "
+		   "[-rxmaxmtu <bytes>] [-rxbind] [-allow-dotted-principals] "
+		   "[-auditlog <log path>] [-jumbo] [-d <debug level>] "
 		   "[-syslog[=FACILITY]] "
 		   "[-enable_peer_stats] [-enable_process_stats] "
 		   "[-help]\n");
 #else
 	    printf("Usage: vlserver [-p <number of processes>] [-nojumbo] "
+		   "[-rxmaxmtu <bytes>] [-rxbind] [-allow-dotted-principals] "
+		   "[-auditlog <log path>] [-jumbo] [-d <debug level>] "
 		   "[-enable_peer_stats] [-enable_process_stats] "
 		   "[-help]\n");
 #endif
@@ -198,35 +248,41 @@ char	**argv;
     /* Initialize dirpaths */
     if (!(initAFSDirPath() & AFSDIR_SERVER_PATHS_OK)) {
 #ifdef AFS_NT40_ENV
-	ReportErrorEventAlt(AFSEVT_SVR_NO_INSTALL_DIR, 0, argv[0],0);
+	ReportErrorEventAlt(AFSEVT_SVR_NO_INSTALL_DIR, 0, argv[0], 0);
 #endif
-	fprintf(stderr,"%s: Unable to obtain AFS server directory.\n", argv[0]);
+	fprintf(stderr, "%s: Unable to obtain AFS server directory.\n",
+		argv[0]);
 	exit(2);
-    } 
+    }
     vl_dbaseName = AFSDIR_SERVER_VLDB_FILEPATH;
 
-    OpenLog(AFSDIR_SERVER_VLOG_FILEPATH);   /* set up logging */
-    SetupLogSignals(); 
+#ifndef AFS_NT40_ENV
+    serverLogSyslogTag = "vlserver";
+#endif
+    OpenLog(AFSDIR_SERVER_VLOG_FILEPATH);	/* set up logging */
+    SetupLogSignals();
 
     tdir = afsconf_Open(AFSDIR_SERVER_ETC_DIRPATH);
     if (!tdir) {
-	printf("vlserver: can't open configuration files in dir %s, giving up.\n", AFSDIR_SERVER_ETC_DIRPATH);
+	printf
+	    ("vlserver: can't open configuration files in dir %s, giving up.\n",
+	     AFSDIR_SERVER_ETC_DIRPATH);
 	exit(1);
     }
-#ifdef AFS_NT40_ENV 
+#ifdef AFS_NT40_ENV
     /* initialize winsock */
-    if (afs_winsockInit()<0) {
-      ReportErrorEventAlt(AFSEVT_SVR_WINSOCK_INIT_FAILED, 0,
-			  argv[0],0);
-      fprintf(stderr, "vlserver: couldn't initialize winsock. \n");
-      exit(1);
+    if (afs_winsockInit() < 0) {
+	ReportErrorEventAlt(AFSEVT_SVR_WINSOCK_INIT_FAILED, 0, argv[0], 0);
+	fprintf(stderr, "vlserver: couldn't initialize winsock. \n");
+	exit(1);
     }
 #endif
     /* get this host */
-    gethostname(hostname,sizeof(hostname));
+    gethostname(hostname, sizeof(hostname));
     th = gethostbyname(hostname);
     if (!th) {
-	printf("vlserver: couldn't get address of this host (%s).\n", hostname);
+	printf("vlserver: couldn't get address of this host (%s).\n",
+	       hostname);
 	exit(1);
     }
     memcpy(&myHost, th->h_addr, sizeof(afs_int32));
@@ -235,35 +291,61 @@ char	**argv;
     signal(SIGXCPU, CheckSignal_Signal);
 #endif
     /* get list of servers */
-    code = afsconf_GetExtendedCellInfo(tdir,(char *)0, AFSCONF_VLDBSERVICE,
-                                       &info, &clones);
+    code =
+	afsconf_GetExtendedCellInfo(tdir, NULL, AFSCONF_VLDBSERVICE, &info,
+				    &clones);
     if (code) {
 	printf("vlserver: Couldn't get cell server list for 'afsvldb'.\n");
 	exit(2);
     }
 
-    vldb_confdir = tdir;		/* Preserve our configuration dir */
+    vldb_confdir = tdir;	/* Preserve our configuration dir */
     /* rxvab no longer supported */
     memset(&tkey, 0, sizeof(tkey));
 
-    if (noAuth) afsconf_SetNoAuthFlag(tdir, 1);
+    if (noAuth)
+	afsconf_SetNoAuthFlag(tdir, 1);
+
+    if (rxBind) {
+	afs_int32 ccode;
+#ifndef AFS_NT40_ENV
+        if (AFSDIR_SERVER_NETRESTRICT_FILEPATH || 
+            AFSDIR_SERVER_NETINFO_FILEPATH) {
+            char reason[1024];
+            ccode = parseNetFiles(SHostAddrs, NULL, NULL,
+				  ADDRSPERSITE, reason,
+				  AFSDIR_SERVER_NETINFO_FILEPATH,
+				  AFSDIR_SERVER_NETRESTRICT_FILEPATH);
+        } else 
+#endif	
+	{
+            ccode = rx_getAllAddr(SHostAddrs, ADDRSPERSITE);
+        }
+        if (ccode == 1) {
+            host = SHostAddrs[0];
+	    rx_InitHost(host, htons(AFSCONF_VLDBPORT));
+	}
+    }
 
     ubik_nBuffers = 512;
     ubik_CRXSecurityProc = afsconf_ClientAuth;
-    ubik_CRXSecurityRock = (char *) tdir;
+    ubik_CRXSecurityRock = (char *)tdir;
     ubik_SRXSecurityProc = afsconf_ServerAuth;
-    ubik_SRXSecurityRock = (char *) tdir;
+    ubik_SRXSecurityRock = (char *)tdir;
     ubik_CheckRXSecurityProc = afsconf_CheckAuth;
-    ubik_CheckRXSecurityRock = (char *) tdir;
-    code = ubik_ServerInitByInfo(myHost, htons(AFSCONF_VLDBPORT), &info,
-				 &clones, vl_dbaseName, &VL_dbase);
+    ubik_CheckRXSecurityRock = (char *)tdir;
+    code =
+	ubik_ServerInitByInfo(myHost, htons(AFSCONF_VLDBPORT), &info, clones,
+			      vl_dbaseName, &VL_dbase);
     if (code) {
-	printf("vlserver: Ubik init failed with code %d\n",code);
+	printf("vlserver: Ubik init failed with code %d\n", code);
 	exit(2);
     }
     if (!rxJumbograms) {
-        rx_maxReceiveSize = OLD_MAX_PACKET_SIZE;
-	rxi_nSendFrags = rxi_nRecvFrags = 1;
+	rx_SetNoJumbo();
+    }
+    if (rxMaxMTU != -1) {
+	rx_SetMaxMTU(rxMaxMTU);
     }
     rx_SetRxDeadTime(50);
 
@@ -271,9 +353,15 @@ char	**argv;
     initialize_dstats();
 
     sc[0] = rxnull_NewServerSecurityObject();
-    sc[1] = (struct rx_securityClass *) 0;
-    sc[2] = (struct rx_securityClass *) rxkad_NewServerSecurityObject(0, tdir, afsconf_GetKey, (char *) 0);
-    tservice = rx_NewService(0, USER_SERVICE_ID, "Vldb server", sc, 3, VL_ExecuteRequest);
+    sc[1] = (struct rx_securityClass *)0;
+    sc[2] = rxkad_NewServerSecurityObject(0, tdir, afsconf_GetKey, NULL);
+#ifdef USE_RXKAD_KEYTAB
+    if (rxkad_InitKeytabDecrypt(AFSDIR_SERVER_RXKAD_KEYTAB_FILEPATH) == 0)
+	rxkad_BindKeytabDecrypt(sc[2]);
+#endif
+    tservice =
+	rx_NewServiceHost(host, 0, USER_SERVICE_ID, "Vldb server", sc, 3,
+		      VL_ExecuteRequest);
     if (tservice == (struct rx_service *)0) {
 	printf("vlserver: Could not create VLDB_SERVICE rx service\n");
 	exit(3);
@@ -283,7 +371,15 @@ char	**argv;
 	lwps = 4;
     rx_SetMaxProcs(tservice, lwps);
 
-    tservice = rx_NewService(0, RX_STATS_SERVICE_ID, "rpcstats", sc, 3, RXSTATS_ExecuteRequest);
+    if (rxkadDisableDotCheck) {
+        rx_SetSecurityConfiguration(tservice, RXS_CONFIG_FLAGS,
+                                    (void *)RXS_CONFIG_FLAGS_DISABLE_DOTCHECK,
+                                    NULL);
+    }
+
+    tservice =
+	rx_NewServiceHost(host, 0, RX_STATS_SERVICE_ID, "rpcstats", sc, 3,
+		      RXSTATS_ExecuteRequest);
     if (tservice == (struct rx_service *)0) {
 	printf("vlserver: Could not create rpc stats rx service\n");
 	exit(3);
@@ -291,16 +387,19 @@ char	**argv;
     rx_SetMinProcs(tservice, 2);
     rx_SetMaxProcs(tservice, 4);
 
-    for (commandLine[0]='\0', i=0; i<argc; i++) {
-        if (i > 0) strcat(commandLine, " ");
+    for (commandLine[0] = '\0', i = 0; i < argc; i++) {
+	if (i > 0)
+	    strcat(commandLine, " ");
 	strcat(commandLine, argv[i]);
     }
-    ViceLog(0,("Starting AFS vlserver %d (%s)\n", VLDBVERSION_4, commandLine));
-    printf("%s\n", cml_version_number);    /* Goes to the log */
+    ViceLog(0,
+	    ("Starting AFS vlserver %d (%s)\n", VLDBVERSION_4, commandLine));
+    printf("%s\n", cml_version_number);	/* Goes to the log */
 
     /* allow super users to manage RX statistics */
     rx_SetRxStatUserOk(vldb_rxstat_userok);
 
-    rx_StartServer(1);		    /* Why waste this idle process?? */
-}
+    rx_StartServer(1);		/* Why waste this idle process?? */
 
+    return 0; /* not reachable */
+}
